@@ -2,19 +2,6 @@ from .base import BaseClient as __BaseClient, convert_bool, BaseDictObject as __
 from typing import List as _List
 
 
-class ErrorList(__BaseDictObject):
-    """
-    A list of error responses returned when a request is unsuccessful.
-    """
-
-    def __init__(self, data):
-        super().__init__(data)
-        if "errors" in data:
-            self.errors: _List[Error] = [Error(datum) for datum in data["errors"]]
-        else:
-            self.errors: _List[Error] = []
-
-
 class Error(__BaseDictObject):
     """
     Error response returned when the request is unsuccessful.
@@ -36,10 +23,29 @@ class Error(__BaseDictObject):
             self.details: str = None
 
 
+class ReportDocumentEncryptionDetails(__BaseDictObject):
+    """
+    Encryption details required for decryption of a report document's contents.
+    """
+
+    def __init__(self, data):
+        super().__init__(data)
+        if "standard" in data:
+            self.standard: str = self._get_value(str, "standard")
+        else:
+            self.standard: str = None
+        if "initializationVector" in data:
+            self.initializationVector: str = self._get_value(str, "initializationVector")
+        else:
+            self.initializationVector: str = None
+        if "key" in data:
+            self.key: str = self._get_value(str, "key")
+        else:
+            self.key: str = None
+
+
 class Report(__BaseDictObject):
-    """
-    Detailed information about the report.
-    """
+    """ """
 
     def __init__(self, data):
         super().__init__(data)
@@ -117,9 +123,7 @@ class CreateReportScheduleSpecification(__BaseDictObject):
 
 
 class CreateReportSpecification(__BaseDictObject):
-    """
-    Information required to create the report.
-    """
+    """ """
 
     def __init__(self, data):
         super().__init__(data)
@@ -187,23 +191,8 @@ class ReportSchedule(__BaseDictObject):
             self.nextReportCreationTime: str = None
 
 
-class ReportScheduleList(__BaseDictObject):
-    """
-    A list of report schedules.
-    """
-
-    def __init__(self, data):
-        super().__init__(data)
-        if "reportSchedules" in data:
-            self.reportSchedules: _List[ReportSchedule] = [ReportSchedule(datum) for datum in data["reportSchedules"]]
-        else:
-            self.reportSchedules: _List[ReportSchedule] = []
-
-
-class CreateReportResponse(__BaseDictObject):
-    """
-    Response schema.
-    """
+class CreateReportResult(__BaseDictObject):
+    """ """
 
     def __init__(self, data):
         super().__init__(data)
@@ -220,21 +209,117 @@ class GetReportsResponse(__BaseDictObject):
 
     def __init__(self, data):
         super().__init__(data)
-        if "reports" in data:
-            self.reports: ReportList = self._get_value(ReportList, "reports")
+        if "payload" in data:
+            self.payload: ReportList = self._get_value(ReportList, "payload")
         else:
-            self.reports: ReportList = None
+            self.payload: ReportList = None
         if "nextToken" in data:
             self.nextToken: str = self._get_value(str, "nextToken")
         else:
             self.nextToken: str = None
+        if "errors" in data:
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
+        else:
+            self.errors: ErrorList = None
 
 
-class CreateReportScheduleResponse(__BaseDictObject):
+class CreateReportResponse(__BaseDictObject):
     """
-    Response schema.
+    The response for the createReport operation.
     """
 
+    def __init__(self, data):
+        super().__init__(data)
+        if "payload" in data:
+            self.payload: CreateReportResult = self._get_value(CreateReportResult, "payload")
+        else:
+            self.payload: CreateReportResult = None
+        if "errors" in data:
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
+        else:
+            self.errors: ErrorList = None
+
+
+class CancelReportResponse(__BaseDictObject):
+    """
+    The response for the cancelReport operation.
+    """
+
+    def __init__(self, data):
+        super().__init__(data)
+        if "errors" in data:
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
+        else:
+            self.errors: ErrorList = None
+
+
+class CancelReportScheduleResponse(__BaseDictObject):
+    """
+    The response for the cancelReportSchedule operation.
+    """
+
+    def __init__(self, data):
+        super().__init__(data)
+        if "errors" in data:
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
+        else:
+            self.errors: ErrorList = None
+
+
+class GetReportResponse(__BaseDictObject):
+    """
+    The response for the getReport operation.
+    """
+
+    def __init__(self, data):
+        super().__init__(data)
+        if "payload" in data:
+            self.payload: Report = self._get_value(Report, "payload")
+        else:
+            self.payload: Report = None
+        if "errors" in data:
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
+        else:
+            self.errors: ErrorList = None
+
+
+class GetReportSchedulesResponse(__BaseDictObject):
+    """
+    The response for the getReportSchedules operation.
+    """
+
+    def __init__(self, data):
+        super().__init__(data)
+        if "payload" in data:
+            self.payload: ReportScheduleList = self._get_value(ReportScheduleList, "payload")
+        else:
+            self.payload: ReportScheduleList = None
+        if "errors" in data:
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
+        else:
+            self.errors: ErrorList = None
+
+
+class GetReportScheduleResponse(__BaseDictObject):
+    """
+    The response for the getReportSchedule operation.
+    """
+
+    def __init__(self, data):
+        super().__init__(data)
+        if "payload" in data:
+            self.payload: ReportSchedule = self._get_value(ReportSchedule, "payload")
+        else:
+            self.payload: ReportSchedule = None
+        if "errors" in data:
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
+        else:
+            self.errors: ErrorList = None
+
+
+class CreateReportScheduleResult(__BaseDictObject):
+    """ """
+
     def __init__(self, data):
         super().__init__(data)
         if "reportScheduleId" in data:
@@ -243,10 +328,25 @@ class CreateReportScheduleResponse(__BaseDictObject):
             self.reportScheduleId: str = None
 
 
+class CreateReportScheduleResponse(__BaseDictObject):
+    """
+    The response for the createReportSchedule operation.
+    """
+
+    def __init__(self, data):
+        super().__init__(data)
+        if "payload" in data:
+            self.payload: CreateReportScheduleResult = self._get_value(CreateReportScheduleResult, "payload")
+        else:
+            self.payload: CreateReportScheduleResult = None
+        if "errors" in data:
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
+        else:
+            self.errors: ErrorList = None
+
+
 class ReportDocument(__BaseDictObject):
-    """
-    Information required for the report document.
-    """
+    """ """
 
     def __init__(self, data):
         super().__init__(data)
@@ -258,23 +358,62 @@ class ReportDocument(__BaseDictObject):
             self.url: str = self._get_value(str, "url")
         else:
             self.url: str = None
+        if "encryptionDetails" in data:
+            self.encryptionDetails: ReportDocumentEncryptionDetails = self._get_value(
+                ReportDocumentEncryptionDetails, "encryptionDetails"
+            )
+        else:
+            self.encryptionDetails: ReportDocumentEncryptionDetails = None
         if "compressionAlgorithm" in data:
             self.compressionAlgorithm: str = self._get_value(str, "compressionAlgorithm")
         else:
             self.compressionAlgorithm: str = None
 
 
+class GetReportDocumentResponse(__BaseDictObject):
+    """
+    Response schema.
+    """
+
+    def __init__(self, data):
+        super().__init__(data)
+        if "payload" in data:
+            self.payload: ReportDocument = self._get_value(ReportDocument, "payload")
+        else:
+            self.payload: ReportDocument = None
+        if "errors" in data:
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
+        else:
+            self.errors: ErrorList = None
+
+
+class ErrorList(list, _List["Error"]):
+    """
+    A list of error responses returned when a request is unsuccessful.
+    """
+
+    def __init__(self, data):
+        super().__init__([Error(datum) for datum in data])
+        self.data = data
+
+
 class ReportList(list, _List["Report"]):
-    """
-    A list of reports.
-    """
+    """ """
 
     def __init__(self, data):
         super().__init__([Report(datum) for datum in data])
         self.data = data
 
 
-class Reports20210630Client(__BaseClient):
+class ReportScheduleList(list, _List["ReportSchedule"]):
+    """ """
+
+    def __init__(self, data):
+        super().__init__([ReportSchedule(datum) for datum in data])
+        self.data = data
+
+
+class Reports20200904Client(__BaseClient):
     def getReports(
         self,
         reportTypes: _List[str] = None,
@@ -293,7 +432,7 @@ class Reports20210630Client(__BaseClient):
         | 0.0222 | 10 |
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
         """
-        url = f"/reports/2021-06-30/reports"
+        url = f"/reports/2020-09-04/reports"
         params = {}
         if reportTypes is not None:
             params["reportTypes"] = ",".join(map(str, reportTypes))
@@ -316,14 +455,14 @@ class Reports20210630Client(__BaseClient):
         )
         response_type = {
             200: GetReportsResponse,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            400: GetReportsResponse,
+            401: GetReportsResponse,
+            403: GetReportsResponse,
+            404: GetReportsResponse,
+            415: GetReportsResponse,
+            429: GetReportsResponse,
+            500: GetReportsResponse,
+            503: GetReportsResponse,
         }.get(response.status_code, None)
         return None if response_type is None else response_type(self._get_response_json(response))
 
@@ -339,7 +478,7 @@ class Reports20210630Client(__BaseClient):
         | 0.0167 | 15 |
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
         """
-        url = f"/reports/2021-06-30/reports"
+        url = f"/reports/2020-09-04/reports"
         params = {}
         response = self.request(
             path=url,
@@ -349,14 +488,14 @@ class Reports20210630Client(__BaseClient):
         )
         response_type = {
             202: CreateReportResponse,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            400: CreateReportResponse,
+            401: CreateReportResponse,
+            403: CreateReportResponse,
+            404: CreateReportResponse,
+            415: CreateReportResponse,
+            429: CreateReportResponse,
+            500: CreateReportResponse,
+            503: CreateReportResponse,
         }.get(response.status_code, None)
         return None if response_type is None else response_type(self._get_response_json(response))
 
@@ -372,7 +511,7 @@ class Reports20210630Client(__BaseClient):
         | 2.0 | 15 |
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
         """
-        url = f"/reports/2021-06-30/reports/{reportId}"
+        url = f"/reports/2020-09-04/reports/{reportId}"
         params = {}
         response = self.request(
             path=url,
@@ -380,15 +519,15 @@ class Reports20210630Client(__BaseClient):
             params=params,
         )
         response_type = {
-            200: Report,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            200: GetReportResponse,
+            400: GetReportResponse,
+            401: GetReportResponse,
+            403: GetReportResponse,
+            404: GetReportResponse,
+            415: GetReportResponse,
+            429: GetReportResponse,
+            500: GetReportResponse,
+            503: GetReportResponse,
         }.get(response.status_code, None)
         return None if response_type is None else response_type(self._get_response_json(response))
 
@@ -404,7 +543,7 @@ class Reports20210630Client(__BaseClient):
         | 0.0222 | 10 |
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
         """
-        url = f"/reports/2021-06-30/reports/{reportId}"
+        url = f"/reports/2020-09-04/reports/{reportId}"
         params = {}
         response = self.request(
             path=url,
@@ -412,15 +551,15 @@ class Reports20210630Client(__BaseClient):
             params=params,
         )
         response_type = {
-            200: None,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            200: CancelReportResponse,
+            400: CancelReportResponse,
+            401: CancelReportResponse,
+            403: CancelReportResponse,
+            404: CancelReportResponse,
+            415: CancelReportResponse,
+            429: CancelReportResponse,
+            500: CancelReportResponse,
+            503: CancelReportResponse,
         }.get(response.status_code, None)
         return None if response_type is None else response_type(self._get_response_json(response))
 
@@ -436,7 +575,7 @@ class Reports20210630Client(__BaseClient):
         | 0.0222 | 10 |
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
         """
-        url = f"/reports/2021-06-30/schedules"
+        url = f"/reports/2020-09-04/schedules"
         params = {}
         if reportTypes is not None:
             params["reportTypes"] = ",".join(map(str, reportTypes))
@@ -446,15 +585,15 @@ class Reports20210630Client(__BaseClient):
             params=params,
         )
         response_type = {
-            200: ReportScheduleList,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            200: GetReportSchedulesResponse,
+            400: GetReportSchedulesResponse,
+            401: GetReportSchedulesResponse,
+            403: GetReportSchedulesResponse,
+            404: GetReportSchedulesResponse,
+            415: GetReportSchedulesResponse,
+            429: GetReportSchedulesResponse,
+            500: GetReportSchedulesResponse,
+            503: GetReportSchedulesResponse,
         }.get(response.status_code, None)
         return None if response_type is None else response_type(self._get_response_json(response))
 
@@ -470,7 +609,7 @@ class Reports20210630Client(__BaseClient):
         | 0.0222 | 10 |
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
         """
-        url = f"/reports/2021-06-30/schedules"
+        url = f"/reports/2020-09-04/schedules"
         params = {}
         response = self.request(
             path=url,
@@ -480,14 +619,14 @@ class Reports20210630Client(__BaseClient):
         )
         response_type = {
             201: CreateReportScheduleResponse,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            400: CreateReportScheduleResponse,
+            401: CreateReportScheduleResponse,
+            403: CreateReportScheduleResponse,
+            404: CreateReportScheduleResponse,
+            415: CreateReportScheduleResponse,
+            429: CreateReportScheduleResponse,
+            500: CreateReportScheduleResponse,
+            503: CreateReportScheduleResponse,
         }.get(response.status_code, None)
         return None if response_type is None else response_type(self._get_response_json(response))
 
@@ -503,7 +642,7 @@ class Reports20210630Client(__BaseClient):
         | 0.0222 | 10 |
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
         """
-        url = f"/reports/2021-06-30/schedules/{reportScheduleId}"
+        url = f"/reports/2020-09-04/schedules/{reportScheduleId}"
         params = {}
         response = self.request(
             path=url,
@@ -511,15 +650,15 @@ class Reports20210630Client(__BaseClient):
             params=params,
         )
         response_type = {
-            200: ReportSchedule,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            200: GetReportScheduleResponse,
+            400: GetReportScheduleResponse,
+            401: GetReportScheduleResponse,
+            403: GetReportScheduleResponse,
+            404: GetReportScheduleResponse,
+            415: GetReportScheduleResponse,
+            429: GetReportScheduleResponse,
+            500: GetReportScheduleResponse,
+            503: GetReportScheduleResponse,
         }.get(response.status_code, None)
         return None if response_type is None else response_type(self._get_response_json(response))
 
@@ -535,7 +674,7 @@ class Reports20210630Client(__BaseClient):
         | 0.0222 | 10 |
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
         """
-        url = f"/reports/2021-06-30/schedules/{reportScheduleId}"
+        url = f"/reports/2020-09-04/schedules/{reportScheduleId}"
         params = {}
         response = self.request(
             path=url,
@@ -543,15 +682,15 @@ class Reports20210630Client(__BaseClient):
             params=params,
         )
         response_type = {
-            200: None,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            200: CancelReportScheduleResponse,
+            400: CancelReportScheduleResponse,
+            401: CancelReportScheduleResponse,
+            403: CancelReportScheduleResponse,
+            404: CancelReportScheduleResponse,
+            415: CancelReportScheduleResponse,
+            429: CancelReportScheduleResponse,
+            500: CancelReportScheduleResponse,
+            503: CancelReportScheduleResponse,
         }.get(response.status_code, None)
         return None if response_type is None else response_type(self._get_response_json(response))
 
@@ -560,14 +699,14 @@ class Reports20210630Client(__BaseClient):
         reportDocumentId: str,
     ):
         """
-                Returns the information required for retrieving a report document's contents.
+                Returns the information required for retrieving a report document's contents. This includes a presigned URL for the report document as well as the information required to decrypt the document's contents.
         **Usage Plan:**
         | Rate (requests per second) | Burst |
         | ---- | ---- |
         | 0.0167 | 15 |
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
         """
-        url = f"/reports/2021-06-30/documents/{reportDocumentId}"
+        url = f"/reports/2020-09-04/documents/{reportDocumentId}"
         params = {}
         response = self.request(
             path=url,
@@ -575,14 +714,14 @@ class Reports20210630Client(__BaseClient):
             params=params,
         )
         response_type = {
-            200: ReportDocument,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            200: GetReportDocumentResponse,
+            400: GetReportDocumentResponse,
+            401: GetReportDocumentResponse,
+            403: GetReportDocumentResponse,
+            404: GetReportDocumentResponse,
+            415: GetReportDocumentResponse,
+            429: GetReportDocumentResponse,
+            500: GetReportDocumentResponse,
+            503: GetReportDocumentResponse,
         }.get(response.status_code, None)
         return None if response_type is None else response_type(self._get_response_json(response))
