@@ -1,87 +1,105 @@
-from .base import BaseClient as __BaseClient
+from .base import BaseClient as __BaseClient, convert_bool, BaseDictObject as __BaseDictObject
 from typing import List as _List
 
 
-class GetServiceJobByServiceJobIdResponse:
+class GetServiceJobByServiceJobIdResponse(__BaseDictObject):
+    """
+    The response schema for the GetServiceJobByServiceJobId operation.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "payload" in data:
-            self.payload: ServiceJob = ServiceJob(data["payload"])
+            self.payload: ServiceJob = self._get_value(ServiceJob, "payload")
         else:
             self.payload: ServiceJob = None
         if "errors" in data:
-            self.errors: ErrorList = ErrorList(data["errors"])
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
         else:
             self.errors: ErrorList = None
 
 
-class CancelServiceJobByServiceJobIdResponse:
+class CancelServiceJobByServiceJobIdResponse(__BaseDictObject):
+    """
+    Response schema for CancelServiceJobByServiceJobId operation.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "errors" in data:
-            self.errors: ErrorList = ErrorList(data["errors"])
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
         else:
             self.errors: ErrorList = None
 
 
-class CompleteServiceJobByServiceJobIdResponse:
+class CompleteServiceJobByServiceJobIdResponse(__BaseDictObject):
+    """
+    Response schema for CompleteServiceJobByServiceJobId operation.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "errors" in data:
-            self.errors: ErrorList = ErrorList(data["errors"])
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
         else:
             self.errors: ErrorList = None
 
 
-class GetServiceJobsResponse:
+class GetServiceJobsResponse(__BaseDictObject):
+    """
+    Response schema for GetJobs operation.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "payload" in data:
-            self.payload: JobListing = JobListing(data["payload"])
+            self.payload: JobListing = self._get_value(JobListing, "payload")
         else:
             self.payload: JobListing = None
         if "errors" in data:
-            self.errors: ErrorList = ErrorList(data["errors"])
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
         else:
             self.errors: ErrorList = None
 
 
-class SetAppointmentResponse:
+class SetAppointmentResponse(__BaseDictObject):
+    """
+    Response schema for add or reschedule appointment operation.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "appointmentId" in data:
-            self.appointmentId: AppointmentId = AppointmentId(data["appointmentId"])
+            self.appointmentId: AppointmentId = self._get_value(AppointmentId, "appointmentId")
         else:
             self.appointmentId: AppointmentId = None
         if "warnings" in data:
-            self.warnings: WarningList = WarningList(data["warnings"])
+            self.warnings: WarningList = self._get_value(WarningList, "warnings")
         else:
             self.warnings: WarningList = None
         if "errors" in data:
-            self.errors: ErrorList = ErrorList(data["errors"])
+            self.errors: ErrorList = self._get_value(ErrorList, "errors")
         else:
             self.errors: ErrorList = None
 
 
-class JobListing:
+class JobListing(__BaseDictObject):
+    """
+    The payload for the GetJobs operation.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "totalResultSize" in data:
-            self.totalResultSize: int = int(data["totalResultSize"])
+            self.totalResultSize: int = self._get_value(int, "totalResultSize")
         else:
             self.totalResultSize: int = None
         if "nextPageToken" in data:
-            self.nextPageToken: str = str(data["nextPageToken"])
+            self.nextPageToken: str = self._get_value(str, "nextPageToken")
         else:
             self.nextPageToken: str = None
         if "previousPageToken" in data:
-            self.previousPageToken: str = str(data["previousPageToken"])
+            self.previousPageToken: str = self._get_value(str, "previousPageToken")
         else:
             self.previousPageToken: str = None
         if "jobs" in data:
@@ -90,32 +108,35 @@ class JobListing:
             self.jobs: _List[ServiceJob] = []
 
 
-class ServiceJob:
+class ServiceJob(__BaseDictObject):
+    """
+    The job details of a service.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "createTime" in data:
-            self.createTime: str = str(data["createTime"])
+            self.createTime: str = self._get_value(str, "createTime")
         else:
             self.createTime: str = None
         if "serviceJobId" in data:
-            self.serviceJobId: ServiceJobId = ServiceJobId(data["serviceJobId"])
+            self.serviceJobId: ServiceJobId = self._get_value(ServiceJobId, "serviceJobId")
         else:
             self.serviceJobId: ServiceJobId = None
         if "serviceJobStatus" in data:
-            self.serviceJobStatus: str = str(data["serviceJobStatus"])
+            self.serviceJobStatus: str = self._get_value(str, "serviceJobStatus")
         else:
             self.serviceJobStatus: str = None
         if "scopeOfWork" in data:
-            self.scopeOfWork: ScopeOfWork = ScopeOfWork(data["scopeOfWork"])
+            self.scopeOfWork: ScopeOfWork = self._get_value(ScopeOfWork, "scopeOfWork")
         else:
             self.scopeOfWork: ScopeOfWork = None
         if "seller" in data:
-            self.seller: Seller = Seller(data["seller"])
+            self.seller: Seller = self._get_value(Seller, "seller")
         else:
             self.seller: Seller = None
         if "serviceJobProvider" in data:
-            self.serviceJobProvider: ServiceJobProvider = ServiceJobProvider(data["serviceJobProvider"])
+            self.serviceJobProvider: ServiceJobProvider = self._get_value(ServiceJobProvider, "serviceJobProvider")
         else:
             self.serviceJobProvider: ServiceJobProvider = None
         if "preferredAppointmentTimes" in data:
@@ -129,15 +150,15 @@ class ServiceJob:
         else:
             self.appointments: _List[Appointment] = []
         if "serviceOrderId" in data:
-            self.serviceOrderId: OrderId = OrderId(data["serviceOrderId"])
+            self.serviceOrderId: OrderId = self._get_value(OrderId, "serviceOrderId")
         else:
             self.serviceOrderId: OrderId = None
         if "marketplaceId" in data:
-            self.marketplaceId: str = str(data["marketplaceId"])
+            self.marketplaceId: str = self._get_value(str, "marketplaceId")
         else:
             self.marketplaceId: str = None
         if "buyer" in data:
-            self.buyer: Buyer = Buyer(data["buyer"])
+            self.buyer: Buyer = self._get_value(Buyer, "buyer")
         else:
             self.buyer: Buyer = None
         if "associatedItems" in data:
@@ -145,25 +166,28 @@ class ServiceJob:
         else:
             self.associatedItems: _List[AssociatedItem] = []
         if "serviceLocation" in data:
-            self.serviceLocation: ServiceLocation = ServiceLocation(data["serviceLocation"])
+            self.serviceLocation: ServiceLocation = self._get_value(ServiceLocation, "serviceLocation")
         else:
             self.serviceLocation: ServiceLocation = None
 
 
-class ScopeOfWork:
+class ScopeOfWork(__BaseDictObject):
+    """
+    The scope of work for the order.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "asin" in data:
-            self.asin: str = str(data["asin"])
+            self.asin: str = self._get_value(str, "asin")
         else:
             self.asin: str = None
         if "title" in data:
-            self.title: str = str(data["title"])
+            self.title: str = self._get_value(str, "title")
         else:
             self.title: str = None
         if "quantity" in data:
-            self.quantity: int = int(data["quantity"])
+            self.quantity: int = self._get_value(int, "quantity")
         else:
             self.quantity: int = None
         if "requiredSkills" in data:
@@ -172,76 +196,91 @@ class ScopeOfWork:
             self.requiredSkills: _List[str] = []
 
 
-class Seller:
+class Seller(__BaseDictObject):
+    """
+    Information about the seller of the service job.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "sellerId" in data:
-            self.sellerId: str = str(data["sellerId"])
+            self.sellerId: str = self._get_value(str, "sellerId")
         else:
             self.sellerId: str = None
 
 
-class ServiceJobProvider:
+class ServiceJobProvider(__BaseDictObject):
+    """
+    Information about the service job provider.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "serviceJobProviderId" in data:
-            self.serviceJobProviderId: str = str(data["serviceJobProviderId"])
+            self.serviceJobProviderId: str = self._get_value(str, "serviceJobProviderId")
         else:
             self.serviceJobProviderId: str = None
 
 
-class Buyer:
+class Buyer(__BaseDictObject):
+    """
+    Information about the buyer.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "buyerId" in data:
-            self.buyerId: str = str(data["buyerId"])
+            self.buyerId: str = self._get_value(str, "buyerId")
         else:
             self.buyerId: str = None
         if "name" in data:
-            self.name: str = str(data["name"])
+            self.name: str = self._get_value(str, "name")
         else:
             self.name: str = None
         if "phone" in data:
-            self.phone: str = str(data["phone"])
+            self.phone: str = self._get_value(str, "phone")
         else:
             self.phone: str = None
         if "isPrimeMember" in data:
-            self.isPrimeMember: bool = bool(data["isPrimeMember"])
+            self.isPrimeMember: bool = self._get_value(convert_bool, "isPrimeMember")
         else:
             self.isPrimeMember: bool = None
 
 
-class AppointmentTime:
+class AppointmentTime(__BaseDictObject):
+    """
+    The time of the appointment window.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "startTime" in data:
-            self.startTime: str = str(data["startTime"])
+            self.startTime: str = self._get_value(str, "startTime")
         else:
             self.startTime: str = None
         if "durationInMinutes" in data:
-            self.durationInMinutes: int = int(data["durationInMinutes"])
+            self.durationInMinutes: int = self._get_value(int, "durationInMinutes")
         else:
             self.durationInMinutes: int = None
 
 
-class Appointment:
+class Appointment(__BaseDictObject):
+    """
+    The details of an appointment.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "appointmentId" in data:
-            self.appointmentId: AppointmentId = AppointmentId(data["appointmentId"])
+            self.appointmentId: AppointmentId = self._get_value(AppointmentId, "appointmentId")
         else:
             self.appointmentId: AppointmentId = None
         if "appointmentStatus" in data:
-            self.appointmentStatus: str = str(data["appointmentStatus"])
+            self.appointmentStatus: str = self._get_value(str, "appointmentStatus")
         else:
             self.appointmentStatus: str = None
         if "appointmentTime" in data:
-            self.appointmentTime: AppointmentTime = AppointmentTime(data["appointmentTime"])
+            self.appointmentTime: AppointmentTime = self._get_value(AppointmentTime, "appointmentTime")
         else:
             self.appointmentTime: AppointmentTime = None
         if "assignedTechnicians" in data:
@@ -249,35 +288,41 @@ class Appointment:
         else:
             self.assignedTechnicians: _List[Technician] = []
         if "rescheduledAppointmentId" in data:
-            self.rescheduledAppointmentId: AppointmentId = AppointmentId(data["rescheduledAppointmentId"])
+            self.rescheduledAppointmentId: AppointmentId = self._get_value(AppointmentId, "rescheduledAppointmentId")
         else:
             self.rescheduledAppointmentId: AppointmentId = None
         if "poa" in data:
-            self.poa: Poa = Poa(data["poa"])
+            self.poa: Poa = self._get_value(Poa, "poa")
         else:
             self.poa: Poa = None
 
 
-class Technician:
+class Technician(__BaseDictObject):
+    """
+    A technician who is assigned to perform the service job in part or in full.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "technicianId" in data:
-            self.technicianId: str = str(data["technicianId"])
+            self.technicianId: str = self._get_value(str, "technicianId")
         else:
             self.technicianId: str = None
         if "name" in data:
-            self.name: str = str(data["name"])
+            self.name: str = self._get_value(str, "name")
         else:
             self.name: str = None
 
 
-class Poa:
+class Poa(__BaseDictObject):
+    """
+    Proof of Appointment (POA) details.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "appointmentTime" in data:
-            self.appointmentTime: AppointmentTime = AppointmentTime(data["appointmentTime"])
+            self.appointmentTime: AppointmentTime = self._get_value(AppointmentTime, "appointmentTime")
         else:
             self.appointmentTime: AppointmentTime = None
         if "technicians" in data:
@@ -285,249 +330,297 @@ class Poa:
         else:
             self.technicians: _List[Technician] = []
         if "uploadingTechnician" in data:
-            self.uploadingTechnician: str = str(data["uploadingTechnician"])
+            self.uploadingTechnician: str = self._get_value(str, "uploadingTechnician")
         else:
             self.uploadingTechnician: str = None
         if "uploadTime" in data:
-            self.uploadTime: str = str(data["uploadTime"])
+            self.uploadTime: str = self._get_value(str, "uploadTime")
         else:
             self.uploadTime: str = None
         if "poaType" in data:
-            self.poaType: str = str(data["poaType"])
+            self.poaType: str = self._get_value(str, "poaType")
         else:
             self.poaType: str = None
 
 
-class AssociatedItem:
+class AssociatedItem(__BaseDictObject):
+    """
+    Information about an item associated with the service job.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "asin" in data:
-            self.asin: str = str(data["asin"])
+            self.asin: str = self._get_value(str, "asin")
         else:
             self.asin: str = None
         if "title" in data:
-            self.title: str = str(data["title"])
+            self.title: str = self._get_value(str, "title")
         else:
             self.title: str = None
         if "quantity" in data:
-            self.quantity: int = int(data["quantity"])
+            self.quantity: int = self._get_value(int, "quantity")
         else:
             self.quantity: int = None
         if "orderId" in data:
-            self.orderId: OrderId = OrderId(data["orderId"])
+            self.orderId: OrderId = self._get_value(OrderId, "orderId")
         else:
             self.orderId: OrderId = None
         if "itemStatus" in data:
-            self.itemStatus: str = str(data["itemStatus"])
+            self.itemStatus: str = self._get_value(str, "itemStatus")
         else:
             self.itemStatus: str = None
         if "brandName" in data:
-            self.brandName: str = str(data["brandName"])
+            self.brandName: str = self._get_value(str, "brandName")
         else:
             self.brandName: str = None
         if "itemDelivery" in data:
-            self.itemDelivery: ItemDelivery = ItemDelivery(data["itemDelivery"])
+            self.itemDelivery: ItemDelivery = self._get_value(ItemDelivery, "itemDelivery")
         else:
             self.itemDelivery: ItemDelivery = None
 
 
-class ItemDelivery:
+class ItemDelivery(__BaseDictObject):
+    """
+    Delivery information for the item.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "estimatedDeliveryDate" in data:
-            self.estimatedDeliveryDate: str = str(data["estimatedDeliveryDate"])
+            self.estimatedDeliveryDate: str = self._get_value(str, "estimatedDeliveryDate")
         else:
             self.estimatedDeliveryDate: str = None
         if "itemDeliveryPromise" in data:
-            self.itemDeliveryPromise: ItemDeliveryPromise = ItemDeliveryPromise(data["itemDeliveryPromise"])
+            self.itemDeliveryPromise: ItemDeliveryPromise = self._get_value(ItemDeliveryPromise, "itemDeliveryPromise")
         else:
             self.itemDeliveryPromise: ItemDeliveryPromise = None
 
 
-class ItemDeliveryPromise:
+class ItemDeliveryPromise(__BaseDictObject):
+    """
+    Promised delivery information for the item.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "startTime" in data:
-            self.startTime: str = str(data["startTime"])
+            self.startTime: str = self._get_value(str, "startTime")
         else:
             self.startTime: str = None
         if "endTime" in data:
-            self.endTime: str = str(data["endTime"])
+            self.endTime: str = self._get_value(str, "endTime")
         else:
             self.endTime: str = None
 
 
-class ServiceLocation:
+class ServiceLocation(__BaseDictObject):
+    """
+    Information about the location of the service job.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "serviceLocationType" in data:
-            self.serviceLocationType: str = str(data["serviceLocationType"])
+            self.serviceLocationType: str = self._get_value(str, "serviceLocationType")
         else:
             self.serviceLocationType: str = None
         if "address" in data:
-            self.address: Address = Address(data["address"])
+            self.address: Address = self._get_value(Address, "address")
         else:
             self.address: Address = None
 
 
-class Address:
+class Address(__BaseDictObject):
+    """
+    The shipping address for the service job.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "name" in data:
-            self.name: str = str(data["name"])
+            self.name: str = self._get_value(str, "name")
         else:
             self.name: str = None
         if "addressLine1" in data:
-            self.addressLine1: str = str(data["addressLine1"])
+            self.addressLine1: str = self._get_value(str, "addressLine1")
         else:
             self.addressLine1: str = None
         if "addressLine2" in data:
-            self.addressLine2: str = str(data["addressLine2"])
+            self.addressLine2: str = self._get_value(str, "addressLine2")
         else:
             self.addressLine2: str = None
         if "addressLine3" in data:
-            self.addressLine3: str = str(data["addressLine3"])
+            self.addressLine3: str = self._get_value(str, "addressLine3")
         else:
             self.addressLine3: str = None
         if "city" in data:
-            self.city: str = str(data["city"])
+            self.city: str = self._get_value(str, "city")
         else:
             self.city: str = None
         if "county" in data:
-            self.county: str = str(data["county"])
+            self.county: str = self._get_value(str, "county")
         else:
             self.county: str = None
         if "district" in data:
-            self.district: str = str(data["district"])
+            self.district: str = self._get_value(str, "district")
         else:
             self.district: str = None
         if "stateOrRegion" in data:
-            self.stateOrRegion: str = str(data["stateOrRegion"])
+            self.stateOrRegion: str = self._get_value(str, "stateOrRegion")
         else:
             self.stateOrRegion: str = None
         if "postalCode" in data:
-            self.postalCode: str = str(data["postalCode"])
+            self.postalCode: str = self._get_value(str, "postalCode")
         else:
             self.postalCode: str = None
         if "countryCode" in data:
-            self.countryCode: str = str(data["countryCode"])
+            self.countryCode: str = self._get_value(str, "countryCode")
         else:
             self.countryCode: str = None
         if "phone" in data:
-            self.phone: str = str(data["phone"])
+            self.phone: str = self._get_value(str, "phone")
         else:
             self.phone: str = None
 
 
-class AddAppointmentRequest:
+class AddAppointmentRequest(__BaseDictObject):
+    """
+    Input for add appointment operation.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "appointmentTime" in data:
-            self.appointmentTime: AppointmentTimeInput = AppointmentTimeInput(data["appointmentTime"])
+            self.appointmentTime: AppointmentTimeInput = self._get_value(AppointmentTimeInput, "appointmentTime")
         else:
             self.appointmentTime: AppointmentTimeInput = None
 
 
-class RescheduleAppointmentRequest:
+class RescheduleAppointmentRequest(__BaseDictObject):
+    """
+    Input for rescheduled appointment operation.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "appointmentTime" in data:
-            self.appointmentTime: AppointmentTimeInput = AppointmentTimeInput(data["appointmentTime"])
+            self.appointmentTime: AppointmentTimeInput = self._get_value(AppointmentTimeInput, "appointmentTime")
         else:
             self.appointmentTime: AppointmentTimeInput = None
         if "rescheduleReasonCode" in data:
-            self.rescheduleReasonCode: RescheduleReasonCode = RescheduleReasonCode(data["rescheduleReasonCode"])
+            self.rescheduleReasonCode: RescheduleReasonCode = self._get_value(
+                RescheduleReasonCode, "rescheduleReasonCode"
+            )
         else:
             self.rescheduleReasonCode: RescheduleReasonCode = None
 
 
-class AppointmentTimeInput:
+class AppointmentTimeInput(__BaseDictObject):
+    """
+    The input appointment time details.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "startTime" in data:
-            self.startTime: str = str(data["startTime"])
+            self.startTime: str = self._get_value(str, "startTime")
         else:
             self.startTime: str = None
         if "durationInMinutes" in data:
-            self.durationInMinutes: int = int(data["durationInMinutes"])
+            self.durationInMinutes: int = self._get_value(int, "durationInMinutes")
         else:
             self.durationInMinutes: int = None
 
 
-class Error:
+class Error(__BaseDictObject):
+    """
+    Error response returned when the request is unsuccessful.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "code" in data:
-            self.code: str = str(data["code"])
+            self.code: str = self._get_value(str, "code")
         else:
             self.code: str = None
         if "message" in data:
-            self.message: str = str(data["message"])
+            self.message: str = self._get_value(str, "message")
         else:
             self.message: str = None
         if "details" in data:
-            self.details: str = str(data["details"])
+            self.details: str = self._get_value(str, "details")
         else:
             self.details: str = None
         if "errorLevel" in data:
-            self.errorLevel: str = str(data["errorLevel"])
+            self.errorLevel: str = self._get_value(str, "errorLevel")
         else:
             self.errorLevel: str = None
 
 
-class Warning:
+class Warning(__BaseDictObject):
+    """
+    Warning returned when the request is successful but execution have some important callouts on basis of which API clients should take defined actions.
+    """
+
     def __init__(self, data):
-        super().__init__()
-        self.data = data
+        super().__init__(data)
         if "code" in data:
-            self.code: str = str(data["code"])
+            self.code: str = self._get_value(str, "code")
         else:
             self.code: str = None
         if "message" in data:
-            self.message: str = str(data["message"])
+            self.message: str = self._get_value(str, "message")
         else:
             self.message: str = None
         if "details" in data:
-            self.details: str = str(data["details"])
+            self.details: str = self._get_value(str, "details")
         else:
             self.details: str = None
 
 
 class ErrorList(list, _List["Error"]):
+    """
+    A list of error responses returned when a request is unsuccessful.
+    """
+
     def __init__(self, data):
         super().__init__([Error(datum) for datum in data])
         self.data = data
 
 
 class WarningList(list, _List["Warning"]):
+    """
+    A list of warnings returned in the sucessful execution response of an API request.
+    """
+
     def __init__(self, data):
         super().__init__([Warning(datum) for datum in data])
         self.data = data
 
 
 class ServiceJobId(str):
-    pass
+    """
+    Amazon identifier for the service job.
+    """
 
 
 class OrderId(str):
-    pass
+    """
+    The Amazon-defined identifier for an order placed by the buyer, in 3-7-7 format.
+    """
 
 
 class AppointmentId(str):
-    pass
+    """
+    The appointment identifier.
+    """
 
 
 class RescheduleReasonCode(str):
-    pass
+    """
+    Appointment reschedule reason code.
+    """
 
 
 class ServicesV1Client(__BaseClient):
@@ -535,12 +628,22 @@ class ServicesV1Client(__BaseClient):
         self,
         serviceJobId: str,
     ):
-        url = "/service/v1/serviceJobs/{serviceJobId}".format(
-            serviceJobId=serviceJobId,
-        )
+        """
+                Gets service job details for the service job indicated by the service job identifier you specify.
+        **Usage Plan:**
+        | Rate (requests per second) | Burst |
+        | ---- | ---- |
+        | 20 | 40 |
+        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
+        """
+        url = f"/service/v1/serviceJobs/{serviceJobId}"
         params = {}
-        response = self.request(url, method="GET", params=params)
-        return {
+        response = self.request(
+            path=url,
+            method="GET",
+            params=params,
+        )
+        response_type = {
             200: GetServiceJobByServiceJobIdResponse,
             400: GetServiceJobByServiceJobIdResponse,
             403: GetServiceJobByServiceJobIdResponse,
@@ -551,21 +654,32 @@ class ServicesV1Client(__BaseClient):
             429: GetServiceJobByServiceJobIdResponse,
             500: GetServiceJobByServiceJobIdResponse,
             503: GetServiceJobByServiceJobIdResponse,
-        }[response.status_code](self._get_response_json(response))
+        }.get(response.status_code, None)
+        return None if response_type is None else response_type(self._get_response_json(response))
 
     def cancelServiceJobByServiceJobId(
         self,
         serviceJobId: str,
         cancellationReasonCode: str,
     ):
-        url = "/service/v1/serviceJobs/{serviceJobId}/cancellations".format(
-            serviceJobId=serviceJobId,
-        )
+        """
+                Cancels the service job indicated by the service job identifier you specify.
+        **Usage Plan:**
+        | Rate (requests per second) | Burst |
+        | ---- | ---- |
+        | 5 | 20 |
+        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
+        """
+        url = f"/service/v1/serviceJobs/{serviceJobId}/cancellations"
         params = {}
         if cancellationReasonCode is not None:
-            params["cancellationReasonCode"] = (cancellationReasonCode,)
-        response = self.request(url, method="PUT", data=data.data)
-        return {
+            params["cancellationReasonCode"] = cancellationReasonCode
+        response = self.request(
+            path=url,
+            method="PUT",
+            params=params,
+        )
+        response_type = {
             200: CancelServiceJobByServiceJobIdResponse,
             400: CancelServiceJobByServiceJobIdResponse,
             403: CancelServiceJobByServiceJobIdResponse,
@@ -576,18 +690,29 @@ class ServicesV1Client(__BaseClient):
             429: CancelServiceJobByServiceJobIdResponse,
             500: CancelServiceJobByServiceJobIdResponse,
             503: CancelServiceJobByServiceJobIdResponse,
-        }[response.status_code](self._get_response_json(response))
+        }.get(response.status_code, None)
+        return None if response_type is None else response_type(self._get_response_json(response))
 
     def completeServiceJobByServiceJobId(
         self,
         serviceJobId: str,
     ):
-        url = "/service/v1/serviceJobs/{serviceJobId}/completions".format(
-            serviceJobId=serviceJobId,
-        )
+        """
+                Completes the service job indicated by the service job identifier you specify.
+        **Usage Plan:**
+        | Rate (requests per second) | Burst |
+        | ---- | ---- |
+        | 5 | 20 |
+        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
+        """
+        url = f"/service/v1/serviceJobs/{serviceJobId}/completions"
         params = {}
-        response = self.request(url, method="PUT", data=data.data)
-        return {
+        response = self.request(
+            path=url,
+            method="PUT",
+            params=params,
+        )
+        response_type = {
             200: CompleteServiceJobByServiceJobIdResponse,
             400: CompleteServiceJobByServiceJobIdResponse,
             403: CompleteServiceJobByServiceJobIdResponse,
@@ -598,7 +723,8 @@ class ServicesV1Client(__BaseClient):
             429: CompleteServiceJobByServiceJobIdResponse,
             500: CompleteServiceJobByServiceJobIdResponse,
             503: CompleteServiceJobByServiceJobIdResponse,
-        }[response.status_code](self._get_response_json(response))
+        }.get(response.status_code, None)
+        return None if response_type is None else response_type(self._get_response_json(response))
 
     def getServiceJobs(
         self,
@@ -616,36 +742,48 @@ class ServicesV1Client(__BaseClient):
         scheduleStartDate: str = None,
         scheduleEndDate: str = None,
     ):
-        url = "/service/v1/serviceJobs".format()
+        """
+                Gets service job details for the specified filter query.
+        **Usage Plan:**
+        | Rate (requests per second) | Burst |
+        | ---- | ---- |
+        | 10 | 40 |
+        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
+        """
+        url = f"/service/v1/serviceJobs"
         params = {}
         if serviceOrderIds is not None:
             params["serviceOrderIds"] = ",".join(map(str, serviceOrderIds))
         if serviceJobStatus is not None:
             params["serviceJobStatus"] = ",".join(map(str, serviceJobStatus))
         if pageToken is not None:
-            params["pageToken"] = (pageToken,)
+            params["pageToken"] = pageToken
         if pageSize is not None:
-            params["pageSize"] = (pageSize,)
+            params["pageSize"] = pageSize
         if sortField is not None:
-            params["sortField"] = (sortField,)
+            params["sortField"] = sortField
         if sortOrder is not None:
-            params["sortOrder"] = (sortOrder,)
+            params["sortOrder"] = sortOrder
         if createdAfter is not None:
-            params["createdAfter"] = (createdAfter,)
+            params["createdAfter"] = createdAfter
         if createdBefore is not None:
-            params["createdBefore"] = (createdBefore,)
+            params["createdBefore"] = createdBefore
         if lastUpdatedAfter is not None:
-            params["lastUpdatedAfter"] = (lastUpdatedAfter,)
+            params["lastUpdatedAfter"] = lastUpdatedAfter
         if lastUpdatedBefore is not None:
-            params["lastUpdatedBefore"] = (lastUpdatedBefore,)
+            params["lastUpdatedBefore"] = lastUpdatedBefore
         if scheduleStartDate is not None:
-            params["scheduleStartDate"] = (scheduleStartDate,)
+            params["scheduleStartDate"] = scheduleStartDate
         if scheduleEndDate is not None:
-            params["scheduleEndDate"] = (scheduleEndDate,)
+            params["scheduleEndDate"] = scheduleEndDate
         if marketplaceIds is not None:
             params["marketplaceIds"] = ",".join(map(str, marketplaceIds))
-        response = self.request(url, method="GET", params=params)
-        return {
+        response = self.request(
+            path=url,
+            method="GET",
+            params=params,
+        )
+        response_type = {
             200: GetServiceJobsResponse,
             400: GetServiceJobsResponse,
             403: GetServiceJobsResponse,
@@ -655,19 +793,31 @@ class ServicesV1Client(__BaseClient):
             429: GetServiceJobsResponse,
             500: GetServiceJobsResponse,
             503: GetServiceJobsResponse,
-        }[response.status_code](self._get_response_json(response))
+        }.get(response.status_code, None)
+        return None if response_type is None else response_type(self._get_response_json(response))
 
     def addAppointmentForServiceJobByServiceJobId(
         self,
         data: AddAppointmentRequest,
         serviceJobId: str,
     ):
-        url = "/service/v1/serviceJobs/{serviceJobId}/appointments".format(
-            serviceJobId=serviceJobId,
-        )
+        """
+                Adds an appointment to the service job indicated by the service job identifier you specify.
+        **Usage Plan:**
+        | Rate (requests per second) | Burst |
+        | ---- | ---- |
+        | 5 | 20 |
+        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
+        """
+        url = f"/service/v1/serviceJobs/{serviceJobId}/appointments"
         params = {}
-        response = self.request(url, method="POST", data=data.data)
-        return {
+        response = self.request(
+            path=url,
+            method="POST",
+            params=params,
+            data=data.data,
+        )
+        response_type = {
             200: SetAppointmentResponse,
             400: SetAppointmentResponse,
             403: SetAppointmentResponse,
@@ -678,7 +828,8 @@ class ServicesV1Client(__BaseClient):
             429: SetAppointmentResponse,
             500: SetAppointmentResponse,
             503: SetAppointmentResponse,
-        }[response.status_code](self._get_response_json(response))
+        }.get(response.status_code, None)
+        return None if response_type is None else response_type(self._get_response_json(response))
 
     def rescheduleAppointmentForServiceJobByServiceJobId(
         self,
@@ -686,13 +837,23 @@ class ServicesV1Client(__BaseClient):
         serviceJobId: str,
         appointmentId: str,
     ):
-        url = "/service/v1/serviceJobs/{serviceJobId}/appointments/{appointmentId}".format(
-            serviceJobId=serviceJobId,
-            appointmentId=appointmentId,
-        )
+        """
+                Reschedules an appointment for the service job indicated by the service job identifier you specify.
+        **Usage Plan:**
+        | Rate (requests per second) | Burst |
+        | ---- | ---- |
+        | 5 | 20 |
+        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
+        """
+        url = f"/service/v1/serviceJobs/{serviceJobId}/appointments/{appointmentId}"
         params = {}
-        response = self.request(url, method="POST", data=data.data)
-        return {
+        response = self.request(
+            path=url,
+            method="POST",
+            params=params,
+            data=data.data,
+        )
+        response_type = {
             200: SetAppointmentResponse,
             400: SetAppointmentResponse,
             403: SetAppointmentResponse,
@@ -703,4 +864,5 @@ class ServicesV1Client(__BaseClient):
             429: SetAppointmentResponse,
             500: SetAppointmentResponse,
             503: SetAppointmentResponse,
-        }[response.status_code](self._get_response_json(response))
+        }.get(response.status_code, None)
+        return None if response_type is None else response_type(self._get_response_json(response))
